package io.gisbi.application.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.gisbi.application.system.domain.User;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

@Mapper
public interface UserMapper extends BaseMapper<User> {


    /***********************************
     * 用途说明：新增系统角色用户对照表 对用户分配角色
     * 参数说明
     * roleid   角色id
     * userid   用户id
     * 返回值说明:
     ************************************/
    boolean addUserRoles(@Param("id") String id, @Param("appid") String appid, @Param("roleid") String roleid,@Param("userid") String userid);

    /***********************************
     * 用途说明：根据用户表id查询角色表所有角色id
     * 参数说明
     * userid     用户id
     * 返回值说明:
     ************************************/
    List<String> getRoleid(@Param("userid") String id);

    /***********************************
     * 用途说明：根据用户id删除所分配的不包含角色
     * 参数说明
     * userid     用户id
     * roleids     多个角色id
     * 返回值说明:
     ************************************/
    void delInRoleUsersByUserid(@Param("userid") String userid,@Param("roleids")String[] roleids);

    /***********************************
     * 用途说明：根据用户id删除所分配的角色
     * 参数说明
     * userid     用户id
     * 返回值说明:
     ************************************/
    boolean delRoleUsersByUserid( @Param("userid")  String id);

    /***********************************
     * 用途说明：根据条件分页查询用户信息
     * 参数说明
     * orgid     所属组织ID
     * nickname   用户昵称
     * page      分页条件
     * 返回值说明:
     ************************************/
    Page<Map<String, Object>> queryUsers(String orgid,String appId, String nickname, Page<User> page);


    /***********************************
     * 用途说明：根据ID删除用户与角色的关联信息
     * 参数说明
     * idList     用户id集合
     * 返回值说明:
     ************************************/
    void delRoleUsersByUserIds(List<String> idList);

    /***********************************
     * 用途说明：根据用户id 和角色id 查询  系统角色用户对照表
     * 参数说明
     * userid   用户id
     * roleid   角色id
     * 返回值说明:
     ************************************/

    List<Map> getRoleUsersByid(@Param("roleid") String roleid,@Param("userid") String userid);
}
